package pathgame.gameplay;

import me.hammerle.snuviengine.api.Engine;
import me.hammerle.snuviengine.api.KeyHandler;
import org.lwjgl.glfw.GLFW;
import pathgame.rendering.MainMenuRenderer;

public class MainMenu
{

    public enum MenuButtons
    {
        START, OPTIONS, EXIT
    }

    public enum KeybindingButtons
    {
        UP, DOWN, LEFT, RIGHT, ESCAPE, CONFIRM, ZOOM_IN, ZOOM_OUT, BACK
    }

    private MenuButtons activeButton = MenuButtons.START;
    private KeybindingButtons activeKeybindingButton = KeybindingButtons.UP;
    private boolean optionsIsActive = false;

    public void tick(Gamestate gamestate)
    {

        if(Keys.UP_KEY.isDown() && Keys.UP_KEY.getTime() == 1 || (Keys.UP_KEY.getTime() >= 20 && Keys.UP_KEY.getTime() % 5 == 1))
        {
            if(optionsIsActive)
            {
                activeKeybindingButton = getPrevButton(activeKeybindingButton);
            }
            else
            {
                activeButton = getPrevButton(activeButton);
            }

            //System.out.println(activeButton);
        }
        else if(Keys.DOWN_KEY.isDown() && Keys.DOWN_KEY.getTime() == 1 || (Keys.DOWN_KEY.getTime() >= 20 && Keys.DOWN_KEY.getTime() % 5 == 1))
        {
            if(optionsIsActive)
            {
                activeKeybindingButton = getNextButton(activeKeybindingButton);
            }
            else
            {

                activeButton = getNextButton(activeButton);
            }
        }
        else if(Keys.CONFIRM_KEY.isDown() && Keys.CONFIRM_KEY.getTime() == 1)
        {
            if(optionsIsActive)
            {
                if(activeKeybindingButton.equals(KeybindingButtons.UP))
                {
                    System.out.println("rebinding");

                    //Todo: Key Rebinding
                    //Keys.UP_KEY.isRebinding();
                    //Keys.UP_KEY.getKey();
                    //Keys.UP_KEY = KeyHandler.register(GLFW.GLFW_KEY_W);
                }
                else if(activeKeybindingButton.equals(KeybindingButtons.BACK))
                {
                    optionsIsActive = false;
                }
            }
            else
            {
                if(activeButton.equals(MenuButtons.EXIT))
                {
                    Engine.stop();
                }
                else if(activeButton.equals(MenuButtons.START))
                {
                    gamestate.setState(Gamestates.GAMEPLAY);
                }
                else if(activeButton.equals(MenuButtons.OPTIONS))
                {
                    optionsIsActive = true;
                }
            }

        }
    }

    public MenuButtons getActiveButton()
    {
        return activeButton;
    }

    public boolean isActiveButton(MenuButtons button)
    {
        return activeButton.equals(button);
    }

    public boolean isActiveButton(KeybindingButtons button)
    {
        return activeKeybindingButton.equals(button);
    }

    public boolean isOptionsIsActive()
    {
        return optionsIsActive;
    }

    private MenuButtons getNextButton(MenuButtons e)
    {
        int index = e.ordinal();
        int nextIndex = index + 1;
        MenuButtons[] btns = MenuButtons.values();
        nextIndex %= btns.length;
        return btns[nextIndex];
    }

    private MenuButtons getPrevButton(MenuButtons e)
    {
        int index = e.ordinal();
        MenuButtons[] btns = MenuButtons.values();
        int nextIndex = index + btns.length - 1;
        nextIndex %= btns.length;
        return btns[nextIndex];
    }

    private KeybindingButtons getPrevButton(KeybindingButtons e)
    {
        int index = e.ordinal();
        KeybindingButtons[] btns = KeybindingButtons.values();
        int nextIndex = index + btns.length - 1;
        nextIndex %= btns.length;
        return btns[nextIndex];
    }

    private KeybindingButtons getNextButton(KeybindingButtons e)
    {
        int index = e.ordinal();
        int nextIndex = index + 1;
        KeybindingButtons[] btns = KeybindingButtons.values();
        nextIndex %= btns.length;
        return btns[nextIndex];
    }

}
