package pathgame.rendering;

import me.hammerle.snuviengine.api.Renderer;
import pathgame.gameplay.Keys;
import pathgame.gameplay.MainMenu;

public class MainMenuRenderer
{

    public void renderTick(Renderer r, float lag, MainMenu menu)
    {
        r.translateTo(0.0f, 0.0f);
        r.scale(2.0f, 2.0f);
        r.updateMatrix();

        if(menu.isOptionsIsActive())
        {
            renderBigBackground(r);

            renderOptionButton("Up Key", Keys.UP_KEY.getName(), r.getViewHeight() * 0.25f - 60 - r.getFontRenderer().getSize("Up Key").getHeight() * 0.5f, menu.isActiveButton(MainMenu.KeybindingButtons.UP), r);
            renderOptionButton("Down Key", Keys.DOWN_KEY.getName(), r.getViewHeight() * 0.25f - 45 - r.getFontRenderer().getSize("Down Key").getHeight() * 0.5f, menu.isActiveButton(MainMenu.KeybindingButtons.DOWN), r);
            renderOptionButton("Left Key", Keys.LEFT_KEY.getName(), r.getViewHeight() * 0.25f - 30 - r.getFontRenderer().getSize("Left Key").getHeight() * 0.5f, menu.isActiveButton(MainMenu.KeybindingButtons.LEFT), r);
            renderOptionButton("Right Key", Keys.RIGHT_KEY.getName(), r.getViewHeight() * 0.25f - 15 - r.getFontRenderer().getSize("Right Key").getHeight() * 0.5f, menu.isActiveButton(MainMenu.KeybindingButtons.RIGHT), r);
            renderOptionButton("Escape Key", Keys.ESCAPE_KEY.getName(), r.getViewHeight() * 0.25f + 0 - r.getFontRenderer().getSize("Escape Key").getHeight() * 0.5f, menu.isActiveButton(MainMenu.KeybindingButtons.ESCAPE), r);
            renderOptionButton("Confirm Key", Keys.CONFIRM_KEY.getName(), r.getViewHeight() * 0.25f + 15 - r.getFontRenderer().getSize("Confirm Key").getHeight() * 0.5f, menu.isActiveButton(MainMenu.KeybindingButtons.CONFIRM), r);
            renderOptionButton("Zoom In Key", Keys.ZOOM_IN_KEY.getName(), r.getViewHeight() * 0.25f + 30 - r.getFontRenderer().getSize("Zoom In Key").getHeight() * 0.5f, menu.isActiveButton(MainMenu.KeybindingButtons.ZOOM_IN), r);
            renderOptionButton("Zoom Out Key", Keys.ZOOM_OUT_KEY.getName(), r.getViewHeight() * 0.25f + 45 - r.getFontRenderer().getSize("Zoom Out Key").getHeight() * 0.5f, menu.isActiveButton(MainMenu.KeybindingButtons.ZOOM_OUT), r);
            renderButton("Back to Main Menu", r.getViewHeight() * 0.25f + 70 - r.getFontRenderer().getSize("Back to Main Menu").getHeight() * 0.5f, menu.isActiveButton(MainMenu.KeybindingButtons.BACK), r);

        }
        else
        {
            renderBackground(r);

            renderButton("Start", r.getViewHeight() * 0.25f - 20 - r.getFontRenderer().getSize("Start").getHeight() * 0.5f, menu.isActiveButton(MainMenu.MenuButtons.START), r);
            renderButton("Options", r.getViewHeight() * 0.25f - r.getFontRenderer().getSize("Options").getHeight() * 0.5f, menu.isActiveButton(MainMenu.MenuButtons.OPTIONS), r);
            renderButton("Exit", r.getViewHeight() * 0.25f + 20 - r.getFontRenderer().getSize("Exit").getHeight() * 0.5f, menu.isActiveButton(MainMenu.MenuButtons.EXIT), r);

        }
    }

    private void renderButton(String text, float y, boolean active, Renderer r)
    {
        r.setMixColorEnabled(false);
        r.setColorEnabled(true);
        r.setTextureEnabled(true);
        String s = text;
        if(active)
        {
            s = "&f" + s;
        }
        else
        {
            s = "&7" + s;
        }
        r.getFontRenderer().drawString(r.getViewWidth() * 0.25f - (r.getFontRenderer().getSize(s).getWidth() * 0.5f), y, s);
    }

    private void renderOptionButton(String text, String binding, float y, boolean active, Renderer r)
    {
        r.setMixColorEnabled(false);
        r.setColorEnabled(true);
        r.setTextureEnabled(true);
        String s = text;
        String b = binding;
        if(active)
        {
            s = "&f" + s;
            b = "&f" + b;
        }
        else
        {
            s = "&7" + s;
            b = "&7" + b;
        }
        //r.getFontRenderer().drawString(r.getViewWidth() * 0.25f - (r.getFontRenderer().getSize(s).getWidth() * 0.5f), y, s+" - "+binding);
        r.getFontRenderer().drawString(50, y, s);
        r.getFontRenderer().drawString(180 - (r.getFontRenderer().getSize(binding).getWidth() * 0.5f), y, b);
    }

    private void renderBackground(Renderer r)
    {
        r.setMixColorEnabled(true);
        r.setColorEnabled(true);
        r.setTextureEnabled(false);
        r.setBlendingEnabled(true);

        r.getColorRenderer().drawRectangle(r.getViewWidth() * 0.25f - 100, r.getViewHeight() * 0.25f - 50, r.getViewWidth() * 0.25f + 100, r.getViewHeight() * 0.25f + 50, 0x33_00_00_00);//ABGR
    }

    private void renderBigBackground(Renderer r)
    {
        r.setMixColorEnabled(true);
        r.setColorEnabled(true);
        r.setTextureEnabled(false);
        r.setBlendingEnabled(true);

        r.getColorRenderer().drawRectangle(r.getViewWidth() * 0.25f - 100, r.getViewHeight() * 0.25f - 75, r.getViewWidth() * 0.25f + 100, r.getViewHeight() * 0.25f + 80, 0x33_00_00_00);//ABGR
    }
}
